@@ -19,7 +19,7 @@ use usbd_serial::{SerialPort, USB_CLASS_CDC};
 use bsp::hal;
 use feather_m0 as bsp;
 
-use bsp::entry;
+use bsp::{entry, periph_alias, pin_alias};
 use hal::clock::{ClockGenId, ClockSource, GenericClockController};
 use hal::delay::Delay;
 use hal::pac::{interrupt, CorePeripherals, Peripherals};
@@ -28,7 +28,6 @@ use hal::rtc;
 use hal::time::U32Ext;
 use hal::usb::UsbBus;
 
-use heapless::consts::U1024;
 use heapless::String;
 
 #[entry]
@@ -52,7 +51,7 @@ fn main() -> ! {
     let rtc_clock = clocks.rtc(&timer_clock).unwrap();
     let timer = rtc::Rtc::clock_mode(peripherals.RTC, rtc_clock.freq(), &mut peripherals.PM);
     let pins = bsp::Pins::new(peripherals.PORT);
-    let mut red_led = pins.d13.into_push_pull_output();
+    let mut red_led: bsp::RedLed = pin_alias!(pins.red_led).into();
 
     red_led.set_high().unwrap();
     delay.delay_ms(500_u32);
@@ -69,9 +68,9 @@ fn main() -> ! {
     };
 
     unsafe {
-        USB_SERIAL = Some(SerialPort::new(&bus_allocator));
+        USB_SERIAL = Some(SerialPort::new(bus_allocator));
         USB_BUS = Some(
-            UsbDeviceBuilder::new(&bus_allocator, UsbVidPid(0x16c0, 0x27dd))
+            UsbDeviceBuilder::new(bus_allocator, UsbVidPid(0x16c0, 0x27dd))
                 .manufacturer("Fake company")
                 .product("Serial port")
                 .serial_number("TEST")
@@ -89,10 +88,11 @@ fn main() -> ! {
     delay.delay_ms(500_u32);
 
     // Now work on the SD peripherals. Slow SPI speed required on init
+    let spi_sercom = periph_alias!(peripherals.spi_sercom);
     let spi = bsp::spi_master(
         &mut clocks,
         400_u32.khz(),
-        peripherals.SERCOM4,
+        spi_sercom,
         &mut peripherals.PM,
         pins.sclk,
         pins.mosi,
@@ -102,14 +102,14 @@ fn main() -> ! {
     red_led.set_high().unwrap();
     delay.delay_ms(500_u32);
 
-    let sd_cd = pins.sd_cd.into_pull_up_input();
-    let mut sd_cs = pins.sd_cs.into_push_pull_output();
+    let sd_cd: bsp::SdCd = pins.sd_cd.into();
+    let mut sd_cs: bsp::SdCs = pins.sd_cs.into();
     sd_cs.set_high().unwrap();
 
     red_led.set_low().unwrap();
     delay.delay_ms(500_u32);
 
-    while USB_DATA_RECEIVED.load(atomic::Ordering::Relaxed) == false {
+    while !USB_DATA_RECEIVED.load(atomic::Ordering::Relaxed) {
         delay.delay_ms(250_u32);
         red_led.toggle().unwrap();
     }
@@ -166,7 +166,7 @@ fn main() -> ! {
 #[macro_export]
 macro_rules! usbserial_write {
     ($($tt:tt)*) => {{
-        let mut s: String<U1024> = String::new();
+        let mut s: String<1024> = String::new();
         write!(s, $($tt)*).unwrap();
         let message_bytes = s.as_bytes();
         let mut total_written = 0;
@@ -192,8 +192,8 @@ static USB_DATA_RECEIVED: atomic::AtomicBool = atomic::AtomicBool::new(false);
 #[interrupt]
 fn USB() {
     unsafe {
-        USB_BUS.as_mut().map(|usb_dev| {
-            USB_SERIAL.as_mut().map(|serial| {
+        if let Some(usb_dev) = USB_BUS.as_mut() {
+            if let Some(serial) = USB_SERIAL.as_mut() {
                 usb_dev.poll(&mut [serial]);
                 let mut buf = [0u8; 16];
                 if let Ok(count) = serial.read(&mut buf) {
@@ -201,7 +201,7 @@ fn USB() {
                         USB_DATA_RECEIVED.store(true, atomic::Ordering::Relaxed);
                     }
                 }
-            });
-        });
+            };
+        };
     };
 }
