@@ -9,18 +9,20 @@ pub use hal::pac;
 
 use hal::clock::GenericClockController;
 use hal::sercom::{
-    v2::{
-        spi,
-        uart::{self, BaudMode, Oversampling},
-        Sercom0, Sercom4,
-    },
-    I2CMaster3,
+    i2c, spi,
+    uart::{self, BaudMode, Oversampling},
 };
 use hal::time::Hertz;
 
 #[cfg(feature = "usb")]
 use hal::usb::{usb_device::bus::UsbBusAllocator, UsbBus};
 
+hal::bsp_peripherals!(
+    SERCOM0 { UartSercom }
+    SERCOM3 { I2cSercom }
+    SERCOM4 { SpiSercom }
+);
+
 /// Definitions related to pins and pin aliases
 pub mod pins {
     use super::hal;
@@ -84,10 +86,16 @@ pub mod pins {
         PA20 {
             /// Pin 6, PWM capable
             name: d6
+            aliases: {
+                PushPullOutput: Ssd1306Dc
+            }
         }
         PA07 {
             /// Pin 9, PWM capable.  Also analog input (A7)
             name: d9
+            aliases: {
+                PushPullOutput: Ssd1306Rst
+            }
         }
         PA18 {
             /// Pin 10, PWM capable
@@ -208,11 +216,17 @@ pub mod pins {
         PA08 {
             /// SD card SPI chip select
             name: sd_cs
+            aliases: {
+                PushPullOutput: SdCs
+            }
         },
         #[cfg(all(feature = "adalogger", not(feature = "rfm"), not(feature = "express")))]
         PA21 {
             /// SD card detect
             name: sd_cd
+            aliases: {
+                PullUpInput: SdCd
+            }
         },
     );
 }
@@ -221,7 +235,7 @@ pub use pins::*;
 /// SPI pads for the labelled SPI peripheral
 ///
 /// You can use these pads with other, user-defined [`spi::Config`]urations.
-pub type SpiPads = spi::Pads<Sercom4, Miso, Mosi, Sclk>;
+pub type SpiPads = spi::Pads<SpiSercom, Miso, Mosi, Sclk>;
 
 /// SPI master for the labelled SPI peripheral
 ///
@@ -229,12 +243,12 @@ pub type SpiPads = spi::Pads<Sercom4, Miso, Mosi, Sclk>;
 pub type Spi = spi::Spi<spi::Config<SpiPads>, spi::Duplex>;
 
 /// Convenience for setting up the labelled SPI peripheral.
-/// This powers up SERCOM4 and configures it for use as an
+/// This powers up the SPI SERCOM and configures it for use as an
 /// SPI Master in SPI Mode 0.
 pub fn spi_master(
     clocks: &mut GenericClockController,
     baud: impl Into<Hertz>,
-    sercom4: pac::SERCOM4,
+    sercom: SpiSercom,
     pm: &mut pac::PM,
     sclk: impl Into<Sclk>,
     mosi: impl Into<Mosi>,
@@ -245,35 +259,44 @@ pub fn spi_master(
     let freq = clock.freq();
     let (miso, mosi, sclk) = (miso.into(), mosi.into(), sclk.into());
     let pads = spi::Pads::default().data_in(miso).data_out(mosi).sclk(sclk);
-    spi::Config::new(pm, sercom4, pads, freq)
+    spi::Config::new(pm, sercom, pads, freq)
         .baud(baud)
         .spi_mode(spi::MODE_0)
         .enable()
 }
 
-/// I2C master for the labelled SDA & SCL pins
-pub type I2C = I2CMaster3<Sda, Scl>;
+/// I2C pads for the labelled I2C peripheral
+///
+/// You can use these pads with other, user-defined [`i2c::Config`]urations.
+pub type I2cPads = i2c::Pads<I2cSercom, Sda, Scl>;
+
+/// I2C master for the labelled I2C peripheral
+///
+/// This type implements [`Read`](ehal::blocking::i2c::Read),
+/// [`Write`](ehal::blocking::i2c::Write) and
+/// [`WriteRead`](ehal::blocking::i2c::WriteRead).
+pub type I2c = i2c::I2c<i2c::Config<I2cPads>>;
 
 /// Convenience for setting up the labelled SDA, SCL pins to
 /// operate as an I2C master running at the specified frequency.
 pub fn i2c_master(
     clocks: &mut GenericClockController,
     baud: impl Into<Hertz>,
-    sercom3: pac::SERCOM3,
+    sercom: I2cSercom,
     pm: &mut pac::PM,
     sda: impl Into<Sda>,
     scl: impl Into<Scl>,
-) -> I2C {
+) -> I2c {
     let gclk0 = clocks.gclk0();
     let clock = &clocks.sercom3_core(&gclk0).unwrap();
+    let freq = clock.freq();
     let baud = baud.into();
-    let sda = sda.into();
-    let scl = scl.into();
-    I2CMaster3::new(clock, baud, sercom3, pm, sda, scl)
+    let pads = i2c::Pads::new(sda.into(), scl.into());
+    i2c::Config::new(pm, sercom, pads, freq).baud(baud).enable()
 }
 
 /// UART pads for the labelled RX & TX pins
-pub type UartPads = uart::Pads<Sercom0, UartRx, UartTx>;
+pub type UartPads = uart::Pads<UartSercom, UartRx, UartTx>;
 
 /// UART device for the labelled RX & TX pins
 pub type Uart = uart::Uart<uart::Config<UartPads>, uart::Duplex>;
@@ -283,7 +306,7 @@ pub type Uart = uart::Uart<uart::Config<UartPads>, uart::Duplex>;
 pub fn uart(
     clocks: &mut GenericClockController,
     baud: impl Into<Hertz>,
-    sercom0: pac::SERCOM0,
+    sercom: UartSercom,
     pm: &mut pac::PM,
     uart_rx: impl Into<UartRx>,
     uart_tx: impl Into<UartTx>,
@@ -292,7 +315,7 @@ pub fn uart(
     let clock = &clocks.sercom0_core(&gclk0).unwrap();
     let baud = baud.into();
     let pads = uart::Pads::default().rx(uart_rx.into()).tx(uart_tx.into());
-    uart::Config::new(pm, sercom0, pads, clock.freq())
+    uart::Config::new(pm, sercom, pads, clock.freq())
         .baud(baud, BaudMode::Fractional(Oversampling::Bits16))
         .enable()
 }
